==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
                WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDetailDescriptionMetadata.b(a);
            a.ad("WebGridClipboardEventDetail", () => new WebGridClipboardEventDetailDescription());
            a.ac("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDetailDescriptionMetadata.$t = markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridClipboardEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescription } from "./WebGridClipboardEventDetailDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDetailDescriptionMetadata.a == null) {
                WebGridClipboardEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDetailDescriptionMetadata.c(WebGridClipboardEventDetailDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridClipboardEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDetailDescriptionMetadata.b(a);
            a.ae("WebGridClipboardEventDetail", () => new WebGridClipboardEventDetailDescription());
            a.ad("WebGridClipboardEventDetail", WebGridClipboardEventDetailDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDetailDescriptionMetadata.$t = markType(WebGridClipboardEventDetailDescriptionMetadata, 'WebGridClipboardEventDetailDescriptionMetadata');
    WebGridClipboardEventDetailDescriptionMetadata.a = null;
    return WebGridClipboardEventDetailDescriptionMetadata;
})();
